@@ -51,25 +51,17 @@ static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 struct _BjbMainViewPriv {  
   GtkWidget        *window;
   GtkWidget        *label;
-  ClutterActor     *bin;
-  ClutterActor     *embed ;
-  ClutterActor     *content;
 
   /* Toolbar */
   BjbMainToolbar   *main_toolbar;
-  ClutterActor     *toolbar_actor;
 
   /* Selection Mode */
-  ClutterActor     *actions ;
   BjbSelectionToolbar  *select_bar;
 
   /* Search Entry  */
-  ClutterActor     *search_actor;
   BjbSearchToolbar *search_bar;
 
   /* View Notes , model */
-  /* TODO : controller is app-wide controller.
-   * add one window specific controller */
   GdMainView       *view ; 
   BjbController    *controller ;
 
@@ -80,7 +72,7 @@ struct _BjbMainViewPriv {
   gulong data;
 };
 
-G_DEFINE_TYPE (BjbMainView, bjb_main_view, CLUTTER_TYPE_ACTOR);
+G_DEFINE_TYPE (BjbMainView, bjb_main_view, GTK_TYPE_BOX);
 
 static void
 bjb_main_view_init (BjbMainView *object)
@@ -183,7 +175,7 @@ switch_to_note_view (BjbMainView *self, BijiNoteObj *note)
 {
   bjb_search_toolbar_disconnect (self->priv->search_bar);
   bjb_main_view_disconnect_handlers (self);
-  bjb_note_view_new (self->priv->window, note);
+  bjb_window_base_switch_to_note (BJB_WINDOW_BASE (self->priv->window), note);
 }
 
 static void
@@ -482,97 +474,52 @@ static void
 bjb_main_view_constructed(GObject *o)
 {
   BjbMainView          *self;
+  GtkBox               *vbox; //self, too
   BjbMainViewPriv      *priv;
-  ClutterActor         *stage, *top, *view, *selection_bar;
-  ClutterLayoutManager *filler, *packer, *switcher, *overlay;
-  ClutterConstraint    *constraint ;
+  GtkOverlay           *overlay;
+  GdRevealer           *revealer;
 
   G_OBJECT_CLASS (bjb_main_view_parent_class)->constructed(G_OBJECT(o));
 
   self = BJB_MAIN_VIEW(o);
   priv = self->priv ;
-  stage = bjb_window_base_get_stage (BJB_WINDOW_BASE (priv->window), MAIN_VIEW);
+  vbox = GTK_BOX (self);
+
+  gtk_box_set_homogeneous (vbox, FALSE);
+  gtk_box_set_spacing (vbox, 0);
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (self), GTK_ORIENTATION_VERTICAL);
 
   priv->view = gd_main_view_new (DEFAULT_VIEW);
   bjb_controller_set_main_view (priv->controller, priv->view);
 
-  /* Probably move this to window_base or delete this */
-  filler = clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_CENTER,
-                                   CLUTTER_BIN_ALIGNMENT_CENTER);
-  priv->bin = clutter_actor_new();
-  clutter_actor_set_name (priv->bin, "main_view:bin");
-  clutter_actor_set_layout_manager(priv->bin,filler);
-  clutter_actor_add_child(stage,priv->bin);
-
-  constraint = clutter_bind_constraint_new (stage, CLUTTER_BIND_SIZE, 0.0);
-  clutter_actor_add_constraint (priv->bin, constraint);
-
-  packer = clutter_box_layout_new();
-  clutter_box_layout_set_orientation(CLUTTER_BOX_LAYOUT(packer),
-                                     CLUTTER_ORIENTATION_VERTICAL);
-
-  priv->embed = clutter_actor_new();
-  clutter_actor_set_layout_manager (priv->embed,packer) ;
-  clutter_actor_add_child (priv->bin, priv->embed) ;
-  clutter_actor_set_x_expand (priv->embed, TRUE);
-  clutter_actor_set_y_expand (priv->embed, TRUE);
-
-  /* Top contains main toolbar and search entry */
-  switcher = clutter_box_layout_new();
-  clutter_box_layout_set_orientation(CLUTTER_BOX_LAYOUT(switcher),
-                                     CLUTTER_ORIENTATION_VERTICAL);
-
-  top = clutter_actor_new();
-  clutter_actor_set_layout_manager(top,switcher);
-
-  clutter_actor_add_child(priv->embed,top);
-
   /* main Toolbar */
-  priv->main_toolbar = bjb_main_toolbar_new(priv->view,self,priv->controller);
-  priv->toolbar_actor = bjb_main_toolbar_get_actor(priv->main_toolbar);
-
-  clutter_actor_add_child(top,priv->toolbar_actor);
-  clutter_actor_set_x_expand (priv->toolbar_actor, TRUE);
+  priv->main_toolbar = bjb_main_toolbar_new (priv->view, self, priv->controller);
+  gtk_box_pack_start (vbox, GTK_WIDGET (priv->main_toolbar), FALSE, FALSE, 0);
 
   /* Search entry toolbar */
-  priv->search_bar = bjb_search_toolbar_new(priv->window,
-                                            top,
-                                            priv->controller);
-  priv->search_actor = bjb_search_toolbar_get_actor(priv->search_bar);
-
-  clutter_actor_add_child(top,priv->search_actor);
-  clutter_actor_set_x_expand (priv->search_actor, TRUE);
-
-  /* Overlay contains : Notes view and selection panel  */
-  overlay = clutter_bin_layout_new(CLUTTER_BIN_ALIGNMENT_CENTER,
-                                   CLUTTER_BIN_ALIGNMENT_CENTER);
-  priv->content = clutter_actor_new();
-  clutter_actor_set_layout_manager(priv->content,overlay);
-
-  clutter_actor_add_child(priv->embed,priv->content);
-  clutter_actor_set_y_expand (priv->content, TRUE);
+  priv->search_bar = bjb_search_toolbar_new (priv->window, priv->controller);
+  revealer = bjb_search_toolbar_get_revealer (priv->search_bar);
+  gtk_box_pack_start (vbox, GTK_WIDGET (revealer), FALSE, FALSE, 0);
 
   /* Main view */
-  view = gtk_clutter_actor_new_with_contents(GTK_WIDGET(priv->view));
-  clutter_actor_add_child(priv->content,view);
-  clutter_actor_set_x_expand (view, TRUE);
-  clutter_actor_set_y_expand (view, TRUE);
+  overlay = GTK_OVERLAY (gtk_overlay_new ());
 
   gd_main_view_set_selection_mode (priv->view, FALSE);
-  gd_main_view_set_model(priv->view,
-                         bjb_controller_get_model(priv->controller));
+  gd_main_view_set_model (priv->view, bjb_controller_get_model(priv->controller));
+
+  gtk_container_add (GTK_CONTAINER (overlay), GTK_WIDGET (priv->view));
+  gtk_box_pack_start (vbox, GTK_WIDGET (overlay), TRUE, TRUE, 0);
 
   /* Selection Panel */
-  priv->select_bar = bjb_selection_toolbar_new (priv->content,priv->view,self);
-  selection_bar = bjb_selection_toolbar_get_actor (priv->select_bar);
-  clutter_actor_add_child (priv->bin, selection_bar);
+  priv->select_bar = bjb_selection_toolbar_new (priv->view, self);
+  gtk_overlay_add_overlay (overlay, GTK_WIDGET (priv->select_bar));
 
   /* Drag n drop */
   gtk_drag_dest_set (GTK_WIDGET (priv->view), GTK_DEST_DEFAULT_ALL,
                      target_list, 1, GDK_ACTION_COPY);
 
   bjb_main_view_connect_signals (self);
-  gtk_widget_show_all (priv->window);
+  gtk_widget_show_all (GTK_WIDGET (self));
 }
 
 static void
@@ -617,12 +564,6 @@ bjb_main_view_new(GtkWidget *win,
                        NULL);
 }
 
-ClutterActor *
-bjb_main_view_get_actor(BjbMainView *b)
-{
-  return b->priv->embed ;
-}
-
 GtkWidget *
 bjb_main_view_get_window(BjbMainView *view)
 {
