@@ -20,7 +20,6 @@
 
 #include "config.h"
 
-#include <clutter-gtk/clutter-gtk.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -33,7 +32,6 @@
 enum
 {
   PROP_0,
-  PROP_ACTOR,
   PROP_BJB_SELECTION,
   PROP_BJB_MAIN_VIEW,
   NUM_PROPERTIES
@@ -49,11 +47,8 @@ struct _BjbSelectionToolbarPrivate
 
   /* sure */
   BjbMainView        *view ;
-  ClutterActor       *actor ;
   GtkWidget          *widget ;
   GdMainView         *selection ;
-  ClutterActor       *parent_actor;
-  ClutterConstraint  *width_constraint ;
 
   /* misc gtk */
   GtkToolItem        *left_group;
@@ -63,27 +58,19 @@ struct _BjbSelectionToolbarPrivate
   GtkWidget          *right_box;
 };
 
-G_DEFINE_TYPE (BjbSelectionToolbar, bjb_selection_toolbar, G_TYPE_OBJECT);
+G_DEFINE_TYPE (BjbSelectionToolbar, bjb_selection_toolbar, GTK_TYPE_TOOLBAR);
 
 static void
 bjb_selection_toolbar_fade_in (BjbSelectionToolbar *self)
 {
-  BjbSelectionToolbarPrivate *priv = self->priv;
-  guint8 opacity;
-
-  opacity = clutter_actor_get_opacity (priv->actor);
-
-  if (opacity != 0)
-    return;
-
-  clutter_actor_set_opacity (priv->actor, 255);
+  gtk_widget_set_opacity (self->priv->widget, 1);
 }
 
 
 static void
 bjb_selection_toolbar_fade_out (BjbSelectionToolbar *self)
 {
-  clutter_actor_set_opacity (self->priv->actor, 0);
+  gtk_widget_set_opacity (self->priv->widget, 0);
 }
 
 static void
@@ -129,39 +116,36 @@ static void
 bjb_selection_toolbar_init (BjbSelectionToolbar *self)
 {
   BjbSelectionToolbarPrivate *priv;
-  GtkWidget                  *bin;
   GtkWidget                  *image;
   GtkStyleContext            *context;
   GdkRGBA                     color = {0.0, 0.0, 0.0, 0.0};
+  GtkToolbar                 *tlbar;
 
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, BJB_TYPE_SELECTION_TOOLBAR, BjbSelectionToolbarPrivate);
   priv = self->priv;
+  priv->widget = GTK_WIDGET (self);
+  tlbar = GTK_TOOLBAR (self);
+
+  gtk_toolbar_set_show_arrow (tlbar, FALSE);
+  gtk_toolbar_set_icon_size (tlbar, GTK_ICON_SIZE_LARGE_TOOLBAR);
+
+  gtk_widget_set_halign (priv->widget, GTK_ALIGN_CENTER);
+  gtk_widget_set_valign (priv->widget, GTK_ALIGN_END);
+  gtk_widget_set_margin_bottom (priv->widget, 40);
+  gtk_widget_set_opacity (priv->widget, 0);
+  gtk_widget_set_size_request (priv->widget, 500, -1);
 
-  priv->widget = gtk_toolbar_new ();
-  gtk_toolbar_set_show_arrow (GTK_TOOLBAR (priv->widget), FALSE);
-  gtk_toolbar_set_icon_size (GTK_TOOLBAR (priv->widget), GTK_ICON_SIZE_LARGE_TOOLBAR);
   context = gtk_widget_get_style_context (priv->widget);
   gtk_style_context_add_class (context, "osd");
 
-  priv->actor = gtk_clutter_actor_new_with_contents (priv->widget);
-  clutter_actor_set_opacity (priv->actor, 0);
-  g_object_set (priv->actor, "show-on-set-parent", FALSE, NULL);
-
-  clutter_actor_set_easing_mode (priv->actor, CLUTTER_EASE_IN_QUAD);
-  clutter_actor_set_easing_duration (priv->actor, 300.0);
-
-  clutter_actor_set_easing_mode (priv->actor, CLUTTER_EASE_OUT_QUAD);
-  clutter_actor_set_easing_duration (priv->actor, 300.0);
-
-  bin = gtk_clutter_actor_get_widget (GTK_CLUTTER_ACTOR (priv->actor));
-  gtk_widget_override_background_color (bin,
+  gtk_widget_override_background_color (priv->widget,
                                         GTK_STATE_FLAG_NORMAL,
                                         &color);
 
   priv->left_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   priv->left_group = gtk_tool_item_new ();
   gtk_container_add (GTK_CONTAINER (priv->left_group), priv->left_box);
-  gtk_toolbar_insert (GTK_TOOLBAR (priv->widget), priv->left_group, -1);
+  gtk_toolbar_insert (tlbar, priv->left_group, -1);
   gtk_widget_show_all (GTK_WIDGET (priv->left_group));
 
   /* Notes tags */
@@ -180,12 +164,12 @@ bjb_selection_toolbar_init (BjbSelectionToolbar *self)
   gtk_separator_tool_item_set_draw (GTK_SEPARATOR_TOOL_ITEM (priv->separator), FALSE);
   gtk_widget_set_visible (GTK_WIDGET (priv->separator), TRUE);
   gtk_tool_item_set_expand (priv->separator, TRUE);
-  gtk_toolbar_insert (GTK_TOOLBAR (priv->widget), priv->separator, -1);
+  gtk_toolbar_insert (tlbar, priv->separator, -1);
 
   priv->right_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   priv->right_group = gtk_tool_item_new ();
   gtk_container_add (GTK_CONTAINER (priv->right_group), priv->right_box);
-  gtk_toolbar_insert (GTK_TOOLBAR (priv->widget), priv->right_group, -1);
+  gtk_toolbar_insert (tlbar, priv->right_group, -1);
   gtk_widget_show_all (GTK_WIDGET (priv->right_group));
 
   /* Trash notes */
@@ -197,7 +181,6 @@ bjb_selection_toolbar_init (BjbSelectionToolbar *self)
   gtk_container_add (GTK_CONTAINER (priv->right_box), priv->toolbar_trash);
 
   gtk_widget_show_all (priv->widget);
-  clutter_actor_show(priv->actor);
 }
 
 static void
@@ -210,9 +193,6 @@ bjb_selection_toolbar_get_property (GObject  *object,
 
   switch (property_id)
   {
-    case PROP_ACTOR:
-      g_value_set_object (value, self->priv->actor);
-      break;
     case PROP_BJB_SELECTION:
       g_value_set_object(value, self->priv->selection);
       break;
@@ -232,9 +212,6 @@ bjb_selection_toolbar_set_property (GObject  *object,
 
   switch (property_id)
   {
-    case PROP_ACTOR:
-      self->priv->parent_actor = g_value_get_object (value);
-      break;
     case PROP_BJB_SELECTION:
       self->priv->selection = g_value_get_object (value);
       break;
@@ -247,30 +224,9 @@ bjb_selection_toolbar_set_property (GObject  *object,
   }
 }
 
-static void
-bjb_selection_toolbar_notify_width (GObject *object,
-                                    GParamSpec *pspec,
-                                    gpointer user_data)
-{
-  BjbSelectionToolbar *self = BJB_SELECTION_TOOLBAR (user_data);
-  BjbSelectionToolbarPrivate *priv = self->priv;
-  
-  gfloat offset = 300.0;
-  gfloat width;
-
-  width = clutter_actor_get_width (priv->parent_actor);
-  if (width > 1000)
-    offset += (width - 1000);
-  else if (width < 600)
-    offset -= (600 - width);
-
-  clutter_bind_constraint_set_offset (CLUTTER_BIND_CONSTRAINT (priv->width_constraint), -1 * offset);
-}
-
 static void
 bjb_selection_toolbar_constructed(GObject *obj)
 {
-  ClutterConstraint *constraint ;
   BjbSelectionToolbar *self = BJB_SELECTION_TOOLBAR(obj);
   BjbSelectionToolbarPrivate *priv = self->priv ;
   
@@ -290,20 +246,6 @@ bjb_selection_toolbar_constructed(GObject *obj)
 
   g_signal_connect(priv->toolbar_trash,"clicked",
                    G_CALLBACK(action_delete_selected_notes),priv->view);
-
-  priv->width_constraint = clutter_bind_constraint_new (priv->parent_actor, CLUTTER_BIND_WIDTH, -300.0); 
-  clutter_actor_add_constraint (priv->actor, priv->width_constraint);
-  
-  g_signal_connect (priv->actor,
-                    "notify::width",
-                    G_CALLBACK (bjb_selection_toolbar_notify_width),
-                    self);
-
-  constraint = clutter_align_constraint_new (priv->parent_actor, CLUTTER_ALIGN_X_AXIS, 0.50);
-  clutter_actor_add_constraint (priv->actor, constraint);
-
-  constraint = clutter_align_constraint_new (priv->parent_actor, CLUTTER_ALIGN_Y_AXIS, 0.95);
-  clutter_actor_add_constraint (priv->actor, constraint);
 }
 
 static void
@@ -316,16 +258,6 @@ bjb_selection_toolbar_class_init (BjbSelectionToolbarClass *class)
   object_class->set_property = bjb_selection_toolbar_set_property ;
   object_class->constructed = bjb_selection_toolbar_constructed ;
 
-  properties[PROP_ACTOR] = g_param_spec_object ("actor",
-                                                "Actor",
-                                                "ParentActor",
-                                                CLUTTER_TYPE_ACTOR,
-                                                G_PARAM_READWRITE |
-                                                G_PARAM_CONSTRUCT |
-                                                G_PARAM_STATIC_STRINGS);
-
-  g_object_class_install_property (object_class,PROP_ACTOR,properties[PROP_ACTOR]);
-
   properties[PROP_BJB_SELECTION] = g_param_spec_object ("selection",
                                                         "Selection",
                                                         "SelectionController",
@@ -352,20 +284,11 @@ bjb_selection_toolbar_class_init (BjbSelectionToolbarClass *class)
 
 
 BjbSelectionToolbar *
-bjb_selection_toolbar_new (ClutterActor *parent_actor,
-                           GdMainView   *selection,
+bjb_selection_toolbar_new (GdMainView   *selection,
                            BjbMainView  *bjb_main_view)
 {
   return g_object_new (BJB_TYPE_SELECTION_TOOLBAR,
-                       "actor", parent_actor, 
                        "selection", selection,
                        "bjbmainview",bjb_main_view,
                        NULL);
 }
-
-
-ClutterActor *
-bjb_selection_toolbar_get_actor (BjbSelectionToolbar *self)
-{
-  return self->priv->actor;
-}
